/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: War.java 1970 2007-10-16 11:49:25Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.ant.archive;

import org.apache.tools.ant.Project;
import org.apache.tools.ant.Task;
import org.apache.tools.ant.types.ZipFileSet;
import org.ow2.easybeans.ant.archive.api.IWar;
import org.ow2.easybeans.ant.archive.exploded.WarExploded;
import org.ow2.easybeans.ant.archive.file.WarFile;
import org.ow2.easybeans.ant.archive.info.WarInfo;

/**
 * Task that creates a War archive (.war file or .war directory).
 * @author Florent Benoit
 */
public class War extends AbsArchive {

    /**
     * Path of the WEB-INF folder.
     */
    private static final String WEBINF_FOLDER = "WEB-INF/";

    /**
     * WEB-INF/lib folder.
     */
    private static final String LIB_FOLDER = WEBINF_FOLDER + "lib/";

    /**
     * WEB-INF/classes folder.
     */
    private static final String CLASSES_FOLDER = WEBINF_FOLDER + "classes/";

    /**
     * Default constructor.
     */
    public War() {
        super();
    }

    /**
     * Add files in WEB-INF/classes folder.
     * @param zipFileSet the fileset that contains the files.
     */
    public void addClasses(final ZipFileSet zipFileSet) {
        zipFileSet.setPrefix(CLASSES_FOLDER);
        addFileSet(zipFileSet);
    }

    /**
     * Add files in WEB-INF/lib folder.
     * @param zipFileSet the fileset that contains the files.
     */
    public void addLib(final ZipFileSet zipFileSet) {
        zipFileSet.setPrefix(LIB_FOLDER);
        addFileSet(zipFileSet);
    }

    /**
     * Add files in WEB-INF folder.
     * @param zipFileSet the fileset that contains the files.
     */
    public void addWebinf(final ZipFileSet zipFileSet) {
        zipFileSet.setPrefix(WEBINF_FOLDER);
        addFileSet(zipFileSet);
    }


    /**
     * Execute the task by using either exploded or file mode.
     */
    @Override
    public void execute() {

        log("Building War in '" + getDest() + "'.", Project.MSG_INFO);

        IWar war = null;

        // 2 cases, exploded mode or not
        if (isExploded()) {
            war = new WarExploded(getProject());
        } else {
            war = new WarFile(getProject());
        }

        // Set the name of the task
        ((Task) war).setTaskName(getTaskName());

        // Build the info object
        WarInfo warInfo = new WarInfo();
        war.setWarInfo(warInfo);

        // Fill archive properties
        updateArchiveInfo(warInfo);

        // Execute the task
        war.execute();

    }

}
